@@ -21,7 +21,9 @@ yet available.
 """
 
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
+
 import calendar
 import datetime
 import re
@@ -150,7 +152,7 @@ class LogsRequester(object):
       finally:
         of.flush()
         if of is not log.out:
-          of.close()  # pytype: disable=attribute-error
+          of.close()
     finally:
       tf.close()
     log.info('Copied %d records.', line_count)
