@@ -39,14 +39,24 @@ from __future__ import division
 from __future__ import unicode_literals
 
 import copy
+import re
 
 from googlecloudsdk.calliope.concepts import deps as deps_lib
+from googlecloudsdk.command_lib.util.apis import registry
+from googlecloudsdk.command_lib.util.apis import yaml_command_schema_util as util
 from googlecloudsdk.core import exceptions
+from googlecloudsdk.core import properties
 from googlecloudsdk.core import resources
-
 import six
 
 
+IGNORED_FIELDS = {
+    'project': 'project',
+    'projectId': 'project',
+    'projectsId': 'project',
+}
+
+
 class Error(exceptions.Error):
   """Base class for errors in this module."""
 
@@ -59,6 +69,16 @@ class ResourceConfigurationError(Error):
   """Raised if a resource is improperly declared."""
 
 
+class InvalidResourceArgumentLists(Error):
+  """Exception for missing, extra, or out of order arguments."""
+
+  def __init__(self, expected, actual):
+    expected = ['[' + e + ']' if e in IGNORED_FIELDS else e for e in expected]
+    super(InvalidResourceArgumentLists, self).__init__(
+        'Invalid resource arguments: Expected [{}], Found [{}].'.format(
+            ', '.join(expected), ', '.join(actual)))
+
+
 class ConceptSpec(object):
   """Base class for concept args."""
 
@@ -104,7 +124,7 @@ class ConceptSpec(object):
     Args:
       attribute_to_args_map: {str: str}, A map of attribute names to the names
         of their associated flags.
-      base_fallthroughs_map: {str: [deps_lib.Fallthrough]} A map of attribute
+      base_fallthroughs_map: {str: [deps.Fallthrough]} A map of attribute
         names to non-argument fallthroughs, including command-level
         fallthroughs.
       parsed_args: the parsed Namespace.
@@ -132,15 +152,15 @@ class _Attribute(object):
 
   Attributes:
     name: The name of the attribute. Used primarily to control the arg or flag
-      name corresponding to the attribute.
+      name corresponding to the attribute. Must be in all lower case.
     help_text: String describing the attribute's relationship to the concept,
       used to generate help for an attribute flag.
     required: True if the attribute is required.
-    fallthroughs: [googlecloudsdk.calliope.concepts.deps.Fallthrough], the list
-      of sources of data, in priority order, that can provide a value for the
-      attribute if not given on the command line. These should only be sources
-      inherent to the attribute, such as associated properties, not command-
-      specific sources.
+    fallthroughs: [googlecloudsdk.calliope.concepts.deps_lib.Fallthrough], the
+      list of sources of data, in priority order, that can provide a value for
+      the attribute if not given on the command line. These should only be
+      sources inherent to the attribute, such as associated properties, not
+      command-specific sources.
     completer: core.cache.completion_cache.Completer, the completer associated
       with the attribute.
     value_type: the type to be accepted by the attribute arg. Defaults to str.
@@ -149,6 +169,13 @@ class _Attribute(object):
   def __init__(self, name, help_text=None, required=False, fallthroughs=None,
                completer=None, value_type=None):
     """Initializes."""
+    # Check for attributes that mix lower- and uppercase. Camel case is not
+    # handled consistently among libraries.
+    if re.search(r'[A-Z]', name) and re.search('r[a-z]', name):
+      raise ValueError(
+          'Invalid attribute name [{}]: Attribute names should be in lower '
+          'snake case (foo_bar) so they can be transformed to flag names.'
+          .format(name))
     self.name = name
     self.help_text = help_text
     self.required = required
@@ -208,6 +235,34 @@ class ResourceSpec(ConceptSpec):
   """Defines a Cloud resource as a set of attributes for argument creation.
   """
 
+  # TODO(b/78851830): update the documentation to use this method.
+  @classmethod
+  def FromYaml(cls, yaml_data, api_version=None):
+    """Constructs an instance of ResourceSpec from yaml data.
+
+    Args:
+      yaml_data: dict, the parsed data from a resources.yaml file under
+        command_lib/.
+      api_version: string, overrides the default version in the resource
+        registry if provided.
+
+    Returns:
+      A ResourceSpec object.
+    """
+    if not yaml_data:
+      return None
+    collection = registry.GetAPICollection(
+        yaml_data['collection'], api_version=api_version)
+    attributes = ParseAttributesFromData(
+        yaml_data.get('attributes'), collection.detailed_params)
+    return cls(
+        resource_collection=collection.full_name,
+        resource_name=yaml_data['name'],
+        api_version=collection.api_version,
+        disable_auto_completers=yaml_data['disable_auto_completers'],
+        plural_name=yaml_data.get('plural_name'),
+        **{attribute.parameter_name: attribute for attribute in attributes})
+
   # TODO(b/67707644): Enable completers by default when confident enough.
   def __init__(self, resource_collection, resource_name='resource',
                api_version=None, disable_auto_completers=True, plural_name=None,
@@ -336,11 +391,16 @@ class ResourceSpec(ConceptSpec):
       return attribute_config.attribute_name
     if anchor:
       return 'name'
-    return param_name
+    return param_name.replace('Id', '_id').lower()
 
   def ParamName(self, attribute_name):
     """Given an attribute name, gets the param name for resource parsing."""
-    return self.attribute_to_params_map.get(attribute_name, '')
+    if attribute_name not in self.attribute_to_params_map:
+      raise ValueError(
+          'No param name found for attribute [{}]. Existing attributes are '
+          '[{}]'.format(attribute_name,
+                        ', '.join(sorted(self.attribute_to_params_map.keys()))))
+    return self.attribute_to_params_map[attribute_name]
 
   def AttributeName(self, param_name):
     """Given a param name, gets the attribute name."""
@@ -456,8 +516,9 @@ class ResourceSpec(ConceptSpec):
       for value in values:
         def F(return_value=value):
           return return_value
-        new_fallthrough = deps_lib.Fallthrough(F, fallthrough.hint,
-                                               active=fallthrough.active)
+
+        new_fallthrough = deps_lib.Fallthrough(
+            F, fallthrough.hint, active=fallthrough.active)
         fallthroughs_map[attribute_name] = [new_fallthrough]
         # Add the anchor fallthroughs for this particular value, so that the
         # error messages will contain the appropriate hints.
@@ -473,11 +534,11 @@ class ResourceSpec(ConceptSpec):
     """Builds map of all fallthroughs including arg names.
 
     Fallthroughs are a list of objects that, when called, try different ways of
-    getting values for attributes (see googlecloudsdk.calliope.concepts.deps.
-    _Fallthrough). This method builds a map from the name of each attribute to
-    its fallthroughs, including the "primary" fallthrough representing its
-    corresponding argument value in parsed_args if any, and any fallthroughs
-    that were configured for the attribute beyond that.
+    getting values for attributes (see googlecloudsdk.calliope.concepts.
+    deps_lib._Fallthrough). This method builds a map from the name of each
+    attribute to its fallthroughs, including the "primary" fallthrough
+    representing its corresponding argument value in parsed_args if any, and any
+    fallthroughs that were configured for the attribute beyond that.
 
     Args:
       attribute_to_args_map: {str: str}, A map of attribute names to the names
@@ -540,9 +601,9 @@ class ResourceSpec(ConceptSpec):
     parameter_name = self.ParamName(attribute.name)
     anchor_based_fallthroughs = [
         deps_lib.FullySpecifiedAnchorFallthrough(
-            anchor_fallthrough, self.collection_info,
-            parameter_name)
-        for anchor_fallthrough in anchor_fallthroughs]
+            anchor_fallthrough, self.collection_info, parameter_name)
+        for anchor_fallthrough in anchor_fallthroughs
+    ]
     return anchor_based_fallthroughs
 
   def _AddAnchorFallthroughs(self, anchor, fallthroughs_map):
@@ -569,9 +630,62 @@ class ResourceSpec(ConceptSpec):
 class ResourceParameterAttributeConfig(object):
   """Configuration used to create attributes from resource parameters."""
 
-  def __init__(self, name=None, help_text=None, fallthroughs=None,
-               completer=None, completion_request_params=None,
-               completion_id_field=None, value_type=None):
+  @classmethod
+  def FromData(cls, data):
+    """Constructs an attribute config from data defined in the yaml file.
+
+    Args:
+      data: {}, the dict of data from the YAML file for this single attribute.
+
+    Returns:
+      ResourceParameterAttributeConfig
+    """
+    if not data:
+      return None
+
+    attribute_name = data['attribute_name']
+    parameter_name = data['parameter_name']
+    help_text = data['help']
+    completion_id_field = data.get('completion_id_field', None)
+    completion_request_params_list = data.get('completion_request_params', [])
+    completion_request_params = {
+        param.get('fieldName'): param.get('value')
+        for param in completion_request_params_list
+    }
+
+    # Add property fallthroughs.
+    fallthroughs = []
+    prop = properties.FromString(data.get('property', ''))
+    if prop:
+      fallthroughs.append(deps_lib.PropertyFallthrough(prop))
+    default_config = DEFAULT_RESOURCE_ATTRIBUTE_CONFIGS.get(attribute_name)
+    if default_config:
+      fallthroughs += [
+          f for f in default_config.fallthroughs if f not in fallthroughs]
+    # Add fallthroughs from python hooks.
+    fallthrough_data = data.get('fallthroughs', [])
+    fallthroughs_from_hook = [
+        deps_lib.Fallthrough(util.Hook.FromPath(f['hook']), hint=f['hint'])
+        for f in fallthrough_data
+    ]
+    fallthroughs += fallthroughs_from_hook
+    return cls(
+        name=attribute_name,
+        help_text=help_text,
+        fallthroughs=fallthroughs,
+        completion_id_field=completion_id_field,
+        completion_request_params=completion_request_params,
+        parameter_name=parameter_name)
+
+  def __init__(self,
+               name=None,
+               help_text=None,
+               fallthroughs=None,
+               completer=None,
+               completion_request_params=None,
+               completion_id_field=None,
+               value_type=None,
+               parameter_name=None):
     """Create a resource attribute.
 
     Args:
@@ -580,8 +694,8 @@ class ResourceParameterAttributeConfig(object):
       help_text: str, generic help text for any flag based on the attribute. One
         special expansion is available to convert "{resource}" to the name of
         the resource.
-      fallthroughs: [deps.Fallthrough], A list of fallthroughs to use to resolve
-        the attribute if it is not provided on the command line.
+      fallthroughs: [deps_lib.Fallthrough], A list of fallthroughs to use to
+        resolve the attribute if it is not provided on the command line.
       completer: core.cache.completion_cache.Completer, the completer
         associated with the attribute.
       completion_request_params: {str: value}, a dict of field names to static
@@ -589,11 +703,80 @@ class ResourceParameterAttributeConfig(object):
       completion_id_field: str, the ID field of the return value in the
         response for completion commands.
       value_type: the type to be accepted by the attribute arg. Defaults to str.
+      parameter_name: the API parameter name that this attribute maps to.
     """
     self.attribute_name = name
     self.help_text = help_text
     self.fallthroughs = fallthroughs or []
+    # The completer is always None because neither the surface nor the yaml
+    # schema allow for specifying completers currently.
     self.completer = completer
     self.completion_request_params = completion_request_params
     self.completion_id_field = completion_id_field
     self.value_type = value_type or six.text_type
+    self.parameter_name = parameter_name
+
+
+def ParseAttributesFromData(attributes_data, expected_param_names):
+  """Parses a list of ResourceParameterAttributeConfig from yaml data.
+
+  Args:
+    attributes_data: dict, the attributes data defined in
+      command_lib/resources.yaml file.
+    expected_param_names: [str], the names of the API parameters that the API
+      method accepts. Example, ['projectsId', 'instancesId'].
+
+  Returns:
+    [ResourceParameterAttributeConfig].
+
+  Raises:
+    InvalidResourceArgumentLists: if the attributes defined in the yaml file
+      don't match the expected fields in the API method.
+  """
+  raw_attributes = [
+      ResourceParameterAttributeConfig.FromData(a) for a in attributes_data
+  ]
+  registered_param_names = [a.parameter_name for a in raw_attributes]
+  final_attributes = []
+
+  # TODO(b/78851830): improve the time complexity here.
+  for expected_name in expected_param_names:
+    if raw_attributes and expected_name == raw_attributes[0].parameter_name:
+      # Attribute matches expected, add it and continue checking.
+      final_attributes.append(raw_attributes.pop(0))
+    elif expected_name in IGNORED_FIELDS:
+      # Attribute doesn't match but is being ignored. Add an auto-generated
+      # attribute as a substitute.
+      # Currently, it would only be the project config.
+      attribute_name = IGNORED_FIELDS[expected_name]
+      ignored_attribute = DEFAULT_RESOURCE_ATTRIBUTE_CONFIGS.get(attribute_name)
+      # Manually add the parameter name, e.g. project, projectId or projectsId.
+      ignored_attribute.parameter_name = expected_name
+      final_attributes.append(ignored_attribute)
+    else:
+      # It doesn't match (or there are no more registered params) and the
+      # field is not being ignored, error.
+      raise InvalidResourceArgumentLists(expected_param_names,
+                                         registered_param_names)
+
+  if raw_attributes:
+    # All expected fields were processed but there are still registered
+    # attribute params remaining, they must be extra.
+    raise InvalidResourceArgumentLists(expected_param_names,
+                                       registered_param_names)
+
+  return final_attributes
+
+
+DEFAULT_PROJECT_ATTRIBUTE_CONFIG = ResourceParameterAttributeConfig(
+    name='project',
+    help_text='The Cloud project for the {resource}.',
+    fallthroughs=[
+        # Typically argument fallthroughs should be configured at the command
+        # level, but the --project flag is currently available in every command.
+        deps_lib.ArgFallthrough('--project'),
+        deps_lib.PropertyFallthrough(properties.VALUES.core.project)
+    ])
+DEFAULT_RESOURCE_ATTRIBUTE_CONFIGS = {
+    'project': DEFAULT_PROJECT_ATTRIBUTE_CONFIG}
+_DEFAULT_CONFIGS = {'project': DEFAULT_PROJECT_ATTRIBUTE_CONFIG}
