@@ -21,10 +21,11 @@ from __future__ import unicode_literals
 from googlecloudsdk.calliope import base
 
 
-@base.ReleaseTracks(base.ReleaseTrack.BETA, base.ReleaseTrack.ALPHA)
 class BigtableV2(base.Group):
   """Manage your Cloud Bigtable storage."""
 
+  category = base.DATABASES_CATEGORY
+
   def Filter(self, context, args):
     del context, args
     base.DisableUserProjectQuota()
