@@ -20,7 +20,9 @@ Google Cloud Storage.
 # TODO(b/67917387): Deprecate this command when `sql import` goes to GA.
 
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
+
 from googlecloudsdk.api_lib.sql import api_util
 from googlecloudsdk.api_lib.sql import operations
 from googlecloudsdk.api_lib.sql import validate
@@ -32,7 +34,8 @@ from googlecloudsdk.core import properties
 from googlecloudsdk.core.console import console_io
 
 
-@base.ReleaseTracks(base.ReleaseTrack.GA, base.ReleaseTrack.BETA)
+@base.ReleaseTracks(base.ReleaseTrack.GA, base.ReleaseTrack.BETA,
+                    base.ReleaseTrack.ALPHA)
 @deprecation_utils.DeprecateCommandAtVersion(
     remove_version='205.0.0', remove=False, alt_command='gcloud sql import sql')
 class Import(base.Command):
